SET NAMES 'UTF8';

ALTER TABLE `cat_configuracion`
   ADD COLUMN `url_sync_cortes` TEXT AFTER `url_sync_ventas`,
   ADD COLUMN `url_sync_retiros` TEXT AFTER `url_sync_cortes`;
ALTER TABLE `tbl_cortes_caja` 
   ADD COLUMN `consolidado` DATETIME NULL AFTER `desglose`;
ALTER TABLE `tbl_retiros` 
   ADD COLUMN `consolidado` DATETIME NULL AFTER `id_usuario_retiro`;

DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateUrls`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateUrls`(
	in_url_empresa TEXT,
	in_url_usuarios TEXT,
	in_url_sucursales TEXT,
	in_url_productos TEXT,
	in_url_precios TEXT,
	in_url_existencias TEXT,
	in_url_ventas TEXT,
	in_url_cortes TEXT,
	in_url_retiros TEXT
)
    COMMENT 'Guarda la configuracion de Urls para sincronizacion de catalogos'
BEGIN
	UPDATE cat_configuracion
	SET url_sync_empresa = in_url_empresa,
		url_sync_usuarios = in_url_usuarios,
		url_sync_sucursales = in_url_sucursales,
		url_sync_productos = in_url_productos,
		url_sync_precios = in_url_precios,
		url_existencias = in_url_existencias,
		url_sync_ventas = in_url_ventas,
		url_sync_cortes = in_url_cortes,
		url_sync_retiros = in_url_retiros;
END$$

DELIMITER ;
DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_configuracion`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_configuracion`()
    SQL SECURITY INVOKER
    COMMENT 'Obtiene la información de configuración'
BEGIN
	SELECT cfg.id_sucursal,
		cfg.default_image,
		cfg.group_len,
		cfg.desglosa_total,
		cfg.cashdrawer_unc,
		cfg.url_existencias,
		cfg.url_sync_empresa,
		cfg.url_sync_sucursales,
		cfg.url_sync_productos,
		cfg.url_sync_precios,
		cfg.url_sync_usuarios,
		cfg.url_sync_ventas,
		cfg.token,
		COALESCE(cfg.logo, '') AS logo,
		cfg.print_hoffset,
		cfg.copias_venta,
		cfg.url_sync_cortes,
		cfg.url_sync_retiros
	FROM cat_configuracion AS cfg;
END$$

DELIMITER ;
DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_syncCortes`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_syncCortes`(
)
    COMMENT 'Recupera el sig. corte de caja pendiente de sincronizar'
BEGIN
    SELECT *
    FROM tbl_cortes_caja AS cc
    WHERE cc.consolidado IS NULL
    ORDER BY cc.id_corte
    LIMIT 1;
END$$

DELIMITER ;
DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_syncRetiros`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_syncRetiros`(
)
    COMMENT 'Recupera el sig. retiro de caja pendiente de sincronizar'
BEGIN
    SELECT *
    FROM tbl_retiros AS re
    WHERE re.consolidado IS NULL
    ORDER BY re.id_retiro
    LIMIT 1;
END$$

DELIMITER ;
DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateSyncCorte`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateSyncCorte`(
	in_id_corte INT
)
    COMMENT 'Marca el corte como sincronizado'
BEGIN
	UPDATE tbl_cortes_caja
	SET consolidado = NOW()
	WHERE id_corte = in_id_corte;
END$$

DELIMITER ;
DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateSyncRetiro`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateSyncRetiro`(
	in_id_retiro INT
)
    COMMENT 'Marca el retiro como sincronizado'
BEGIN
	UPDATE tbl_retiros
	SET consolidado = NOW()
	WHERE id_retiro = in_id_retiro;
END$$

DELIMITER ;
